<template>
  <el-dialog
    v-diadrag
    width="60%"
    top="5vh"
    :visible.sync="innerVisible"
    :fullscreen="isFullScreen"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
    id="part-dialog"
  >
    <template slot="title">
      <i
        :class="isFullScreen ? 'icon-zuixiaohua' : 'icon-quanpingzuidahua'"
        style="position: absolute; right: 52px; float: right"
        @click="fullscreen"
      >
      </i>
      <span>{{ title }}</span>
    </template>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      ref="commonPartTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { getProcessConfigPage } from '@/api/plan/customerorder'
import ttable from '@/views/common/ztt-table'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    parentSelectedObj: {
      type: Object,
      default: null
    },
    parentSelectedIndex: {
      type: Number,
      default: null
    }
  },
  data() {
    return {
      ajaxFun: getProcessConfigPage,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      title: '生产工艺配置单获取列表',
      isFullScreen: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 版本号
          {
            minWidth: '100',
            prop: 'proNo',
            label: '合同编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'proName',
            label: '项目名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'remark1',
            label: '生产规格型号及数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            formatter: (row, column, cellValue) => {
              var formatVal = ''
              if (cellValue) {
                formatVal = cellValue
              }
              return formatVal
            }
          },
          {
            minWidth: '100',
            prop: 'remark2',
            label: '生产要求描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            formatter: (row, column, cellValue) => {
              var formatVal = ''
              if (cellValue) {
                formatVal = cellValue
              }
              return formatVal
            }
          },
          {
            minWidth: '100',
            prop: 'cableCore',
            label: '发泡缆芯',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'modelCore',
            label: '模芯',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'modelSleeve',
            label: '模套',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 三级分类
          {
            minWidth: '100',
            prop: 'sizingModel',
            label: '定径模',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'strandModel',
            label: '过模',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          }
        ],
        materialTypeList: []
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionChange', this.multipleSelection)
      } else {
        this.$emit(
          'listenToPartEvent',
          this.currentRow,
          this.parentSelectedObj,
          this.parentSelectedIndex
        )
      }
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.commonPartTable !== undefined) {
        this.$refs.commonPartTable.getDataList().then((res) => {
          // 修改列
          for (let i = this.table.column.length - 1; i >= 0; i--) {
            if (this.table.column[i].isDynamic) {
              this.table.column.splice(i, 1)
            }
          }
          const tableData = this.$refs.commonPartTable.getTableData()
          console.log(tableData)
          // 判断频率列数
          let cnt = 0
          for (let i = 0; i < tableData.length; i++) {
            cnt = Math.max(cnt, tableData[i].processConfigDataList.length)
          }
          // 动态生成列 频率 最大传送衰减 耦合损耗
          const extCol = []
          for (let i = 0; i < cnt; i++) {
            extCol.push({
              isDynamic: true,
              minWidth: '100',
              prop: 'processConfigDataList_frequency' + i,
              label: '频率',
              sort: true,
              isTrue: true,
              isSearch: false,
              searchInfoType: 'text',
              formatter: (row, column, cellValue) => {
                var formatVal = ''
                cellValue = row.processConfigDataList
                if (cellValue && cellValue.length > i) {
                  formatVal = cellValue[i].frequency
                }
                return formatVal
              }
            })
          }
          for (let i = 0; i < cnt; i++) {
            extCol.push({
              isDynamic: true,
              minWidth: '100',
              prop: 'processConfigDataList_deliveryReduce' + i,
              label: '最大传送衰减',
              sort: true,
              isTrue: true,
              isSearch: false,
              searchInfoType: 'text',
              formatter: (row, column, cellValue) => {
                var formatVal = ''
                cellValue = row.processConfigDataList
                if (cellValue && cellValue.length > i) {
                  formatVal = cellValue[i].deliveryReduce
                }
                return formatVal
              }
            })
          }
          for (let i = 0; i < cnt; i++) {
            extCol.push({
              isDynamic: true,
              minWidth: '100',
              prop: 'processConfigDataList_couplingLoss' + i,
              label: '耦合损耗',
              sort: true,
              isTrue: true,
              isSearch: false,
              searchInfoType: 'text',
              formatter: (row, column, cellValue) => {
                var formatVal = ''
                cellValue = row.processConfigDataList
                if (cellValue && cellValue.length > i) {
                  formatVal = cellValue[i].couplingLoss
                }
                return formatVal
              }
            })
          }
          this.table.column = this.table.column.concat(extCol)
          // console.log(this.table.column)
        })
      }
    },
    // 全屏
    fullscreen() {
      this.isFullScreen = !this.isFullScreen
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },
  mounted() {
    // this.getMaterialType('material_type')
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
